@@ -312,6 +312,8 @@ class PairtreeStorageClient(object):
         @type id: identifier
         @returns: L{PairtreeStorageObject}
         """
+        if id.startswith(self.uri_base):
+            id = id[len(self.uri_base):]
         dirpath = os.path.join(self._id_to_dirpath(id))
         if not os.path.exists(dirpath):
             os.makedirs(dirpath)
@@ -392,7 +394,7 @@ class PairtreeStorageClient(object):
         else:
             return False
 
-    def put_stream(self, id, path, stream_name, bytestream, buffer_size = 1024 * 8):
+    def put_stream(self, id, path, stream_name, bytestream, buffer_size = 1024 * 64):
         """
         Store a stream of bytes into a file within a pairtree object.
 
@@ -429,7 +431,7 @@ class PairtreeStorageClient(object):
                 except:
                     pass
                 if not buffer_size:
-                    buffer_size = 1024 * 8
+                    buffer_size = 1024 * 64
                 chunk = bytestream.read(buffer_size)
                 while chunk:
                     f.write(chunk)
@@ -657,7 +659,12 @@ class PairtreeStorageClient(object):
         if not id:
             id = self._get_new_id()
             return self._create(id)
-        elif self.exists(id):
+        
+        
+        if id.startswith(self.uri_base):
+            id = id[len(self.uri_base):]
+             
+        if self.exists(id):
             return PairtreeStorageObject(id, self)
         elif create_if_doesnt_exist:
             return self._create(id)
